@@ -28,6 +28,8 @@
 #include "io_ddir.h"
 #include "ioengine.h"
 #include "iolog.h"
+#include "profiles.h"
+#include "helpers.h"
 
 #ifdef FIO_HAVE_GUASI
 #include <guasi.h>
@@ -264,6 +266,20 @@ struct thread_options {
 	 * I/O Error handling
 	 */
 	unsigned int continue_on_error;
+
+	/*
+	 * Benchmark profile type
+	 */
+	unsigned int profile;
+
+	/*
+	 * blkio cgroup support
+	 */
+	char *cgroup;
+	unsigned int cgroup_weight;
+
+	unsigned int uid;
+	unsigned int gid;
 };
 
 #define FIO_VERROR_SIZE	128
@@ -343,7 +359,7 @@ struct thread_data {
 	/*
 	 * Rate state
 	 */
-	unsigned long rate_usec_cycle[2];
+	unsigned long rate_nsec_cycle[2];
 	long rate_pending_usleep[2];
 	unsigned long rate_bytes[2];
 	unsigned long rate_blocks[2];
